//
//  AmityChatVideoTableViewCell.swift
//  SampleApp
//
//  Created by Manuchet Rungraksa on 27/9/2565 BE.
//  Copyright © 2565 BE David Zhang. All rights reserved.
//

import Foundation
import AmitySDK
import AVKit

final class AmityChatVideoTableViewCell: UITableViewCell, AmityChatCellProtocol {
    @IBOutlet weak var myImageView: UIImageView!
    @IBOutlet weak var displayNameLabel: UILabel!
    @IBOutlet weak var timeLabel: UILabel!
    @IBOutlet weak var messageStatusImageView: UIImageView!

    private var messageId: String?

    var aspectRatioConstraint: NSLayoutConstraint? {
        didSet {
            if let oldValue = oldValue {
                oldValue.isActive = false
            }
            if let aspectRatioConstraint = aspectRatioConstraint {
                aspectRatioConstraint.isActive = true
            }
        }
    }
    
    var messageRepo: AmityMessageRepository!
    
    var fileRepo = AmityFileRepository(client: AmityManager.shared.client!)
    
    private func set(image: UIImage) {
        myImageView.image = image
    }

    func display(_ message: AmityMessage, client: AmityClient) {
        messageId = message.messageId

        if message.isDeleted {
            timeLabel.text = "Message Deleted"
            displayNameLabel.text = "Message Deleted"
        } else {
            let flagCount = message.flagCount
            
            displayNameLabel.text = message.user?.displayName ?? "" + " F: (\(flagCount)"
            messageStatusImageView.image = message.syncState.symbolImage()
            messageStatusImageView.accessibilityIdentifier = "chat.message-cell.statusImageView-\(message.syncState)"
            timeLabel.text = DateFormatter.localizedString(from: message.createdAt, dateStyle: .none, timeStyle: .short)
            messageRepo = AmityMessageRepository(client: client)

            guard !message.isDeleted else {
                self.aspectRatioConstraint = self.myImageView.widthAnchor.constraint(equalTo: self.myImageView.heightAnchor,
                multiplier: 1)
                self.myImageView.image = UIImage(named:"picture")
                self.myImageView.tintColor = UIColor.gray
                return
            }
                        
            if message.messageType == .video {
                
                if message.syncState == .synced {
                    guard let thumbnailFileId = message.data?["thumbnailFileId"] as? String, !thumbnailFileId.isEmpty else { return }
                    guard let imageData = message.getVideoThumbnailInfo() else { return }
                    
                    ImageMessageHandler.shared.fetchImage(fileURL: imageData.fileURL) { [weak self] (image) in
                        self?.updateImage(image: image)
                    }
                }
            }
        }
    }
    
    func updateImage(image: UIImage?) {
        guard let image = image else { return }
        
        let aspect = image.size.width / image.size.height
        self.aspectRatioConstraint = self.myImageView.widthAnchor.constraint(equalTo: self.myImageView.heightAnchor, multiplier: aspect)
        self.myImageView.image = image
    }

    override func prepareForReuse() {
        super.prepareForReuse()
        aspectRatioConstraint = nil
        myImageView.image = nil
        timeLabel.text = ""
        messageStatusImageView.image = nil
    }
}
