//
//  UnreadCountLabelController.swift
//  SampleApp
//
//  Created by Federico Zanetello on 5/8/19.
//  Copyright © 2019 David Zhang. All rights reserved.
//

import UIKit
import AmitySDK
import Combine

/// Updates the given `UILable` `text` with the current unread count
final class UnreadCountLabelController {
    private let unreadCountLabel: UILabel
    private var observation: NSKeyValueObservation?
    
    private var disposeBag: Set<AnyCancellable> = []

    init(unreadCountLabel: UILabel, repository: AmityChannelRepository) {
        self.unreadCountLabel = unreadCountLabel

        updateLabel(count: repository.totalDefaultSubChannelUnreadCount)
        trackUnreadCount(repository: repository)
    }

    private func trackUnreadCount(repository: AmityChannelRepository) {
        repository.$totalDefaultSubChannelUnreadCount.sink { [weak self] unreadCount in
            self?.updateLabel(count: unreadCount)
        }.store(in: &disposeBag)
    }

    private func updateLabel(count: Int) {
        unreadCountLabel.text = count.description
    }
}
