//
//  SDKModel+Extension.swift
//  SampleApp
//
//  Created by Nishan Niraula on 11/24/21.
//  Copyright © 2021 David Zhang. All rights reserved.
//

import Foundation
import AmitySDK

extension AmityPost {
    
    var modelDescription: String {
        return """
            Post:
            
            Id: \(self.postId)
            Data Type: \(self.dataType)
            Data: \(String(describing: self.data))
            Child Posts Count: \(self.childrenPosts.count ?? 0)
            Reactions Count: \(self.reactionsCount)
            Reactions: \(String(describing: self.reactions))
            Flag Count: \(self.flagCount)
            Comments Count: \(self.commentsCount)
            Target Community: \(self.targetCommunity?.communityId ?? "")
            Deleted Status: \(self.isDeleted)
            """
    }
}

extension AmityUser {
    
    var modelDescription: String {
        
        let userRoles = self.roles as? [String] ?? []
        
        return """
            User:
            
            Id: \(self.userId)
            Display Name: \(self.displayName ?? "-")
            User Description: \(self.userDescription)
            Roles: \(userRoles.joined(separator: ","))
            Flag Count: \(self.flagCount)
            Avatar FileId: \(self.avatarFileId ?? "")
            Avatar Custom URL: \(self.avatarCustomUrl ?? "")
            """
    }
}

extension AmityCommunity {
    
    var modelDescription: String {
        return """
            Community:
            
            Id: \(self.communityId)
            Display Name: \(self.displayName)
            Description: \(self.communityDescription)
            Channel Id: \(self.channelId)
            Post Count: \(self.postsCount)
            Members Count: \(self.membersCount)
            Public Status: \(self.isPublic)
            Joined Status: \(self.isJoined)
            Deleted Status: \(self.isDeleted)
                        
            Post Settings: \(self.postSettings.title)
            Only Admin Can Post: \(self.onlyAdminCanPost)
            Post Review Enabled: \(self.isPostReviewEnabled)
            Avatar File Id: \(self.avatar?.fileId ?? "")
            Avatar File URL: \(self.avatar?.fileURL ?? "")
            """
    }
}

extension AmityComment {
    
    var modelDescription: String {
        return """
            Comment:
            
            Id: \(self.commentId)
            Data: \(String(describing: self.data))
            ReferenceId: \(self.referenceId)
            ReferenceType: \(self.referenceType.description)
            UserId: \(self.userId)
            Data Type: \(self.dataType.description)
            Reactions: \(String(describing: self.reactions))
            My Reactions: \(self.myReactions)
            Flag Count: \(self.flagCount)
            Replies Count: \(self.childrenNumber)
            Deleted Status: \(self.isDeleted)
            Sync State: \(self.syncState.description)
            """
    }
}

extension AmityCommentReferenceType {
    
    var description: String {
        switch self {
        case .content:
            return "Content"
        case .post:
            return "Post"
        @unknown default:
            return ""
        }
    }
}

extension AmityDataType {
    
    var description: String {
        switch self {
        case .text:
            return "Text"
        default:
            return ""
        }
    }
}

extension AmityChannel {
    
    var modelDescription: String {
        return """
        Channel:
        
        Id: \(self.channelId)
        Type: \(self.channelType.description)
        Metadata: \(self.metadata?.description ?? "")
        Tags: \(self.tags)
        Deleted: \(self.isDeleted)
        Display Name: \(self.displayName ?? "")
        Muted: \(self.isMuted)
        Default Sub Channel Unread Count: \(self.defaultSubChannelUnreadCount)
        Default Sub Channel Has Unread Mention: \(self.defaultSubChannelHasUnreadMention)
        Member Count: \(self.memberCount)
        Moderator Member Count: \(self.moderatorCount)
        Avatar Info: \(self.getAvatarInfo()?.fileId ?? "")
        """
    }
}

extension AmityMessage {
    
    var modelDescription: String {
        return """
        Message:
                
        Id: \(self.messageId)
        User Id: \(self.userId)
        Channel Id: \(self.channelId)
        Type: \(self.messageType.description)
        Data: \(self.data ?? [:])
        Metadata: \(self.metadata?.description ?? "")
        Tags: \(self.tags)
        Deleted: \(self.isDeleted)
        Parent Id: \(self.parentId ?? "")
        Children Count: \(self.childrenNumber)
        Reaction: \(self.reactions ?? [:])
        Create At: \(self.createdAt)
        Flag count: \(self.flagCount)
        """
    }
}

extension AmitySubChannel {
    
    var modelDescription: String {
        return """
        SubChannel:
        
        SubChannel Id: \(self.subChannelId),
        ChannelId: \(self.channelId),
        Display Name: \(self.displayName),
        IsDeleted: \(self.isDeleted),
        Latest Message Id \(self.latestMessageId ?? ""),
        Message Count: \(self.messageCount)
        CreatedAt: \(String(describing: self.createdAt)),
        UpdatedAt: \(String(describing: self.updatedAt)),
        EditedAt: \(String(describing: self.editedAt)),
        """
    }
}
